<template>
  <div class="relative flex items-center gap-1 px-6 rounded-lg bg-scheme-form w-full group border border-gray-200">
      <input v-model="searchBox"
             v-on:keyup.enter="searchBox.length > 0 ? searchChatList() : () => {}"
             class="relative block w-full h-full outline-none border-none py-3 rounded-lg bg-transparent "
             id="input_search_bar" placeholder="Cari Nama / No. Telepon" />
      <div class="relative block w-8 h-8 p-1 cursor-pointer" @click="searchBox.length > 0 ? refreshSearch() : () => {}">
        <svg width="22" height="22" viewBox="0 0 28 28" fill="none" xmlns="http://www.w3.org/2000/svg">
          <rect width="28" height="28" rx="14" fill="#B2B2B2"/>
          <path d="M7.875 7.875L20.125 20.125" stroke="#343434"/>
          <path d="M20.125 7.875L7.875 20.125" stroke="#343434"/>
        </svg>
      </div>
  </div>
</template>

<script setup lang="ts">
import {ref, watch} from "vue";
import {useChatListStore} from "../../stores/chat_list";
import {useGeneralStore} from "../../stores/general";
import debounce from 'lodash.debounce'

const searchBox = ref("")
const chat = useChatListStore()
const general = useGeneralStore()

const searchChatList = async () => {
  chat.currentPage = 1
  chat.isEndPage = false
  chat.searchString = searchBox.value
  await chat.fetchChatListByGroup(chat.tabName, true,{
    name: searchBox.value
  }).then((resp) => {
    if(chat.list.length > 0 && chat.isFirstOpenChat){
    
      general.isShowProfile = false
      general.showUploadMedia = false
      general.fileUploadMedia = []
      
      chat.selectedChat = chat.list[0].user_chat_id
      chat.selectedChatType = 'whatsapp'
      general.showListOrder = false

      if(chat.firstText == ''){
        chat.isFirstOpenChat = false
      }
    }else{
      if(chat.firstText == ''){
        chat.isFirstOpenChat = false
      }
    }
  })
}

const refreshSearch = async () => {
  searchBox.value = ''
}

// watch(() => chat.tabName,(value) => {
//   searchBox.value = ""
// })

watch(() => chat.searchString, (value) => {
  searchBox.value = value
})

defineExpose(() => {
  searchBox.value
})

watch(searchBox, debounce(async () => {
  // chat.isSearch = !!searchBox.value;
  // chat.searchString = searchBox.value
  // chat.filterData.name = searchBox.value
  await searchChatList()
}, 500))
</script>
